<?php

/**
 * Class DMDI_Row_DsIf_Extension
 */
class DMDI_Row_DsIf_Extension extends ET_Builder_Row
{
    protected $module_credits = [
        'module_uri' => 'https://digimember.de',
        'author' => 'Digital Solutions GmbH',
        'author_uri' => 'https://digimember.de',
    ];

    public function process_dynamic_attrs($original_attrs)
    {
        global $et_fb_processing_shortcode_object;
        $attrs = parent::process_dynamic_attrs($original_attrs);
        return $et_fb_processing_shortcode_object ? array_merge(
            $attrs,
            [
                'ds_if_product_map' => json_encode($this->getDmProducts()),
            ]
        ) : $attrs;
    }

    /**
     * @return array
     */
    private function getDmProducts()
    {
        $dmProducts = digimember_listProducts();
        $arr = ncore_listToArray($dmProducts, 'id', 'name');
        ksort($arr);
        return $arr;
    }

    public function get_fields()
    {
        $this->settings_modal_toggles = array_merge(
            $this->settings_modal_toggles,
            [
                'general' => array_merge(
                    $this->settings_modal_toggles['general'],
                    [
                        'toggles' => array_merge(
                            $this->settings_modal_toggles['general']['toggles'],
                            [
                                'ds_if' => [
                                    'title' => esc_html__('DigiMember [ds_if] protection', 'dmdi-digimember-divi'),
                                    'priority' => 1,
                                ],
                            ]
                        ),
                    ]
                ),
            ]
        );
        $dmProducts = $this->getDmProducts();

        return array_merge(
            parent::get_fields(),
            [
                'ds_if_enable' => [
                    'label' => esc_html__('Enable protection', 'dmdi-digimember-divi'),
                    'type' => 'yes_no_button',
                    'options' => [
                        'off' => esc_html__('No', 'et_builder'),
                        'on' => esc_html__('Yes', 'et_builder'),
                    ],
                    'default' => 'off',
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'affects' => [
                        'ds_if_has_product',
                        'ds_if_has_not_product',
                        'ds_if_logged_in',
                        'ds_if_mode',
                        'ds_if_product_map',
                    ],
                    'toggle_slug' => 'ds_if',
                ],
            ],
            [
                'ds_if_product_map' => [
                    'type' => 'hidden',
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'toggle_slug' => 'ds_if',
                    'depends_show_if' => 'on',
                ],
            ],
            [
                'ds_if_has_product' => [
                    'label' => esc_html__('has product', 'dmdi-digimember-divi'),
                    'type' => 'multiple_checkboxes',
                    'options' => $dmProducts,
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'toggle_slug' => 'ds_if',
                    'depends_show_if' => 'on',
                ],
            ],
            [
                'ds_if_has_not_product' => [
                    'label' => esc_html__('has not product', 'dmdi-digimember-divi'),
                    'type' => 'multiple_checkboxes',
                    'options' => $dmProducts,
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'toggle_slug' => 'ds_if',
                    'depends_show_if' => 'on',
                ],
            ],
            [
                'ds_if_logged_in' => [
                    'label' => esc_html__('is logged in', 'dmdi-digimember-divi'),
                    'type' => 'select',
                    'options' => [
                        '' => '&nbsp;',
                        'yes' => esc_html__('Yes', 'dmdi-digimember-divi'),
                        'no' => esc_html__('No', 'dmdi-digimember-divi'),
                    ],
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'toggle_slug' => 'ds_if',
                    'depends_show_if' => 'on',
                ],
            ],
            [
                'ds_if_mode' => [
                    'label' => esc_html__('only if', 'dmdi-digimember-divi'),
                    'type' => 'select',
                    'options' => [
                        '' => '&nbsp;',
                        'else' => esc_html__('the previous condition did not match', 'dmdi-digimember-divi'),
                        'finally' => esc_html__('any condition so far did not match', 'dmdi-digimember-divi'),
                    ],
                    'option_category' => 'configuration',
                    'tab_slug' => 'general',
                    'toggle_slug' => 'ds_if',
                    'depends_show_if' => 'on',
                ],
            ]
        );
    }

    public function render($atts, $content = null, $function_name = '')
    {
        // The next line is a fix to trick Divi into thinking that it does not need to wrap this element
        // (It doesn't, as it's a direct extension of the original row!)
        $this->vb_support = 'off';

        $content = parent::render($atts, $content, $function_name);
        if (!class_exists('digimember_ShortCodeController') || !function_exists('dm_api') || !function_exists('ncore_retrieve')) {
            return $content;
        }
        $attrs = $this->attrs_unprocessed;
        if (ncore_retrieve($attrs, 'ds_if_enable', 'off') == 'off') {
            return $content;
        }
        $productMap = ncore_retrieve($attrs, 'ds_if_product_map', null);
        if ($productMap && is_string($productMap)) {
            $productMap = urldecode($productMap);
            $productMap = json_decode($productMap, true);
        }
        if (!is_array($productMap)) {
            $productMap = $this->getDmProducts();
        }
        $productMap = array_keys($productMap);

        $hasProduct = ncore_retrieve($attrs, 'ds_if_has_product', '');
        $hasProduct = $this->process_multiple_checkboxes_field_value($productMap, $hasProduct);
        $hasProduct = str_replace('|', ',', $hasProduct);

        $hasNotProduct = ncore_retrieve($attrs, 'ds_if_has_not_product', '');
        $hasNotProduct = $this->process_multiple_checkboxes_field_value($productMap, $hasNotProduct);
        $hasNotProduct = str_replace('|', ',', $hasNotProduct);

        $loggedIn = ncore_retrieve($attrs, 'ds_if_logged_in', '');
        $mode = ncore_retrieve($attrs, 'ds_if_mode', '');

        $shortcodeController = dm_api()->load->controller('shortcode');
        $shortcodeResult = $shortcodeController->shortcodeIf([
            'has_product' => $hasProduct,
            'has_not_product' => $hasNotProduct,
            'logged_in' => $loggedIn,
            'mode' => $mode,
        ], 'hasPassed');
        return $shortcodeResult == 'hasPassed' ? $content : '<div style="display: none;" class="dmdi-no-render" />';
    }
}

new DMDI_Row_DsIf_Extension;